@@ -42,8 +42,23 @@
 
 ZEND_DECLARE_MODULE_GLOBALS(imlib);
 
-static unsigned char third_and_fourth_arg_force_ref[] = { 4, BYREF_NONE, BYREF_NONE, BYREF_FORCE, BYREF_FORCE };
-static unsigned char second_through_fifth_arg_force_ref[] = { 5, BYREF_NONE, BYREF_FORCE, BYREF_FORCE, BYREF_FORCE, BYREF_FORCE };
+static
+	ZEND_BEGIN_ARG_INFO(third_and_fourth_arg_force_ref, 0)
+		ZEND_ARG_PASS_INFO(0)
+		ZEND_ARG_PASS_INFO(0)
+		ZEND_ARG_PASS_INFO(1)
+		ZEND_ARG_PASS_INFO(1)
+	ZEND_END_ARG_INFO();
+
+static
+	ZEND_BEGIN_ARG_INFO(second_through_fifth_arg_force_ref, 0)
+		ZEND_ARG_PASS_INFO(0)
+		ZEND_ARG_PASS_INFO(1)
+		ZEND_ARG_PASS_INFO(1)
+		ZEND_ARG_PASS_INFO(1)
+		ZEND_ARG_PASS_INFO(1)
+	ZEND_END_ARG_INFO();
+
 static int le_imlib_cr;
 static int le_imlib_font;
 static int le_imlib_img;
@@ -113,13 +128,13 @@ STD_PHP_INI_ENTRY("imlib.font_path",
 		  zend_imlib_globals,
 		  imlib_globals)
 STD_PHP_INI_ENTRY("imlib.min_cache_size","0",PHP_INI_SYSTEM,
-                  OnUpdateInt,min_cache_size,
+                  OnUpdateLong,min_cache_size,
                   zend_imlib_globals,imlib_globals)
 STD_PHP_INI_ENTRY("imlib.max_cache_size","4194304",PHP_INI_SYSTEM,
-                  OnUpdateInt,max_cache_size,
+                  OnUpdateLong,max_cache_size,
                   zend_imlib_globals,imlib_globals)
 STD_PHP_INI_ENTRY("imlib.cache_size","0",PHP_INI_SYSTEM|PHP_INI_PERDIR,
-                  OnUpdateInt,cache_size,
+                  OnUpdateLong,cache_size,
                   zend_imlib_globals,imlib_globals)
 PHP_INI_ENTRY("imlib.font_cache_size","524288",PHP_INI_SYSTEM,
               OnUpdateFontCacheSize)
